@@ -13,8 +13,7 @@
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
 
 # Based on XML::Parser tutorial found at http://www.devshed.com/Server_Side/Perl/PerlXML/PerlXML1/page1.html
@@ -391,6 +390,20 @@ sub lookup_documentation($$$;$)
   return $text;
 }
 
+# void convert_value_to_cpp(\$text)
+# Converts e.g. a property's default value.
+sub convert_value_to_cpp($)
+{
+  my ($text) = @_;
+
+  $$text =~ s"\bFALSE\b"<tt>false</tt>"g;
+  $$text =~ s"\bTRUE\b"<tt>true</tt>"g;
+  $$text =~ s"\bNULL\b"<tt>nullptr</tt>"g;
+
+  # Enumerator names
+  $$text =~ s/\b([A-Z]+)_([A-Z\d_]+)\b/&DocsParser::substitute_enumerator_name($1, $2)/eg;
+}
+
 # void remove_example_code($obj_name, \$text)
 # Removes example code from the text of docs (passed by reference).
 sub remove_example_code($$)
@@ -863,8 +876,7 @@ sub substitute_enumerator_name($$)
 
   my $cxx_name = (($module eq "G") ? "" : (ucfirst(lc($module)) . "::")) . $name;
 
-  print "DocsParser.pm: Assuming the enumerator $c_name shall become $cxx_name.\n";
-
+  #print "DocsParser.pm: Assuming the enumerator $c_name shall become $cxx_name.\n";
   return $cxx_name;
 }
 
