@@ -13,8 +13,7 @@
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
 package Output;
 use strict;
@@ -100,15 +99,11 @@ sub check_deprecation($$$$$$)
     print STDERR "Warning, $main::source: The $entity_name $entity_type" .
       " is deprecated in the .defs file, but not in _WRAP_$wrapper.\n";
   }
-  # Uncomment the following lines some time in the future, when most
-  # signal.defs files have been updated with deprecation information.
-  # generate_extra_defs.cc was updated to generate this info soon after
-  # glibmm 2.47.6.
-  #elsif (!$defs_deprecated && $wrap_deprecated)
-  #{
-  #  print STDERR "Warning, $main::source: The $entity_name $entity_type" .
-  #    " is deprecated in _WRAP_$wrapper, but not in the .defs file.\n";
-  #}
+  elsif (!$defs_deprecated && $wrap_deprecated)
+  {
+    print STDERR "Warning, $main::source: The $entity_name $entity_type" .
+      " is deprecated in _WRAP_$wrapper, but not in the .defs file.\n";
+  }
 }
 
 sub ifdef($$)
@@ -562,7 +557,6 @@ sub output_wrap_ctor($$$$$)
     }
 
     #Ctor Declaration:
-    #TODO: Add explicit.
     $self->append("  explicit " . $objCppfunc->get_declaration($arg_list) . "\n");
 
     my $errthrow = "";
@@ -636,7 +630,7 @@ sub output_wrap_sig_decl($$$$$$$$$$$$$$)
 
   # Create a merged Doxygen comment block for the signal from the looked up
   # docs (the block will also contain a prototype of the slot as an example).
-  my $doxycomment = $objCppfunc->get_refdoc_comment($documentation);
+  my $doxycomment = $objCppfunc->get_refdoc_comment($documentation, $$objCSignal{flags});
 
   # If there was already a previous doxygen comment, we want to merge this
   # one with the previous so it is one big comment. If
@@ -690,12 +684,12 @@ sub output_wrap_sig_decl($$$$$$$$$$$$$$)
 }
 
 # void output_wrap_enum($filename, $line_num, $cpp_type, $c_type,
-#   $comment, $ref_subst_in, $ref_subst_out, $no_gtype, $in_class,
+#   $comment, $ref_subst_in, $ref_subst_out, $no_gtype,
 #   $deprecated, $deprecation_docs, $newin)
-sub output_wrap_enum($$$$$$$$$$$$$)
+sub output_wrap_enum($$$$$$$$$$$$)
 {
   my ($self, $filename, $line_num, $cpp_type, $c_type,
-    $comment, $ref_subst_in, $ref_subst_out, $no_gtype, $in_class,
+    $comment, $ref_subst_in, $ref_subst_out, $no_gtype,
     $deprecated, $deprecation_docs, $newin) = @_;
 
   my $objEnum = GtkDefs::lookup_enum($c_type);
@@ -705,11 +699,10 @@ sub output_wrap_enum($$$$$$$$$$$$$)
     return;
   }
 
-  $objEnum->beautify_values(1);
+  $objEnum->beautify_values();
 
-  my $indent = "  ";
-  $indent .= "  " if ($in_class);
-  my $elements = $objEnum->build_element_list(1, $ref_subst_in, $ref_subst_out, $indent);
+  my $elements = $objEnum->build_element_list($ref_subst_in, $ref_subst_out, "  ");
+  add_m4_quotes(\$elements);
 
   if(!$elements)
   {
@@ -717,57 +710,37 @@ sub output_wrap_enum($$$$$$$$$$$$$)
     return;
   }
 
-  # Chop off the name prefix in the documentation.
-  my $name_prefix = $objEnum->get_name_prefix();
-  unshift(@$ref_subst_in, "^$name_prefix");
-  unshift(@$ref_subst_out, "");
+  my $value_suffix = "Enum";
+  $value_suffix = "Flags" if($$objEnum{flags});
 
   # Get the enum documentation from the parsed docs.
-  $indent = " ";
-  $indent .= "  " if ($in_class);
   my $enum_docs = DocsParser::lookup_enum_documentation("$c_type", "$cpp_type",
-    $indent, $ref_subst_in, $ref_subst_out, $deprecation_docs, $newin);
+    " ", $ref_subst_in, $ref_subst_out, $deprecation_docs, $newin);
 
   # Merge the passed in comment to the existing enum documentation.
-  $comment .= "\n$indent* $enum_docs" if $enum_docs ne "";
+  $comment .= "\n * " . $enum_docs if $enum_docs ne "";
 
-  my $value_suffix = "Enum";
-  $value_suffix = "Flags" if ($$objEnum{flags});
-
-  my $str = sprintf("_ENUM(%s,%s,%s,\`%s\',\`%s\',%d,\`%s\',\`%s\')dnl\n",
+  my $str = sprintf("_ENUM(%s,%s,%s,\`%s\',\`%s\',\`%s\',\`%s\')dnl\n",
     $cpp_type,
     $c_type,
     $value_suffix,
     $elements,
     $no_gtype,
-    $in_class,
     $comment,
     $deprecated
   );
+
   $self->append($str);
 }
 
-sub output_wrap_enum_docs_only($$$$$$$$$$$$)
+sub output_wrap_enum_docs_only($$$$$$$$$$$)
 {
   my ($self, $filename, $line_num, $module_canonical, $cpp_type, $c_type,
-    $comment, $ref_subst_in, $ref_subst_out, $in_class, $deprecation_docs, $newin) = @_;
+    $comment, $ref_subst_in, $ref_subst_out, $deprecation_docs, $newin) = @_;
 
-  my $objEnum = GtkDefs::lookup_enum($c_type);
-  if(!$objEnum)
-  {
-    $self->output_wrap_failed($c_type, "enum defs lookup failed.");
-    return;
-  }
-  # Chop off the name prefix in the documentation.
-  my $name_prefix = $objEnum->get_name_prefix();
-  unshift(@$ref_subst_in, "^$name_prefix");
-  unshift(@$ref_subst_out, "");
-
-  # Get the enum documentation from the parsed docs.
-  my $indent = " ";
-  $indent .= "  " if ($in_class);
+  # Get the existing enum description from the parsed docs.
   my $enum_docs = DocsParser::lookup_enum_documentation("$c_type", "$cpp_type",
-    $indent, $ref_subst_in, $ref_subst_out, $deprecation_docs, $newin);
+    " ", $ref_subst_in, $ref_subst_out, $deprecation_docs, $newin);
 
   if($enum_docs eq "")
   {
@@ -776,10 +749,10 @@ sub output_wrap_enum_docs_only($$$$$$$$$$$$)
   }
 
   # Include the enum docs in the module's enum docs group.
-  $enum_docs .= "\n$indent*\n$indent* \@ingroup ${module_canonical}Enums";
+  $enum_docs .= "\n *\n * \@ingroup ${module_canonical}Enums";
 
   # Merge the passed in comment to the existing enum documentation.
-  $comment = "/** " . $comment . "\n$indent* " . $enum_docs . "\n$indent*/\n";
+  $comment = "/** " . $comment . "\n * " . $enum_docs . "\n */\n";
 
   $self->append($comment);
 }
@@ -805,7 +778,7 @@ sub output_wrap_gerror($$$$$$$$$$$$$)
   # Shouldn't happen, and if it does, I'd like to know that.
   warn if($$objEnum{flags});
 
-  $objEnum->beautify_values(0);
+  $objEnum->beautify_values();
 
   # cut off the module prefix, e.g. GDK_
   my $prefix = $domain;
@@ -815,7 +788,8 @@ sub output_wrap_gerror($$$$$$$$$$$$$)
   unshift(@$ref_subst_in, "^${prefix}_");
   unshift(@$ref_subst_out, "");
 
-  my $elements = $objEnum->build_element_list(0, $ref_subst_in, $ref_subst_out, "    ");
+  my $elements = $objEnum->build_element_list($ref_subst_in, $ref_subst_out, "    ");
+  add_m4_quotes(\$elements);
 
   # Get the enum documentation from the parsed docs.
   my $enum_docs = DocsParser::lookup_enum_documentation("$c_type", "Code",
@@ -841,7 +815,7 @@ sub output_wrap_gerror($$$$$$$$$$$$$)
     # $class_docs has got ` and ' replaced and m4 quotes added in WrapParser::
     # on_comment_doxygen() and extract_preceding_documentation().
     # Fix $extra_class_docs here. $deprecation_docs can contain any characters.
-    DocsParser::add_m4_quotes(\$extra_class_docs);
+    add_m4_quotes(\$extra_class_docs);
     $class_docs .= $extra_class_docs;
   }
 
@@ -875,22 +849,22 @@ sub output_wrap_any_property($$$$$$$$$$)
   my $proxy_suffix = "";
 
   # Read/Write:
-  if($objProperty->get_construct_only() eq 1)
+  if ($objProperty->get_construct_only())
   {
     # construct-only functions can be read, but not written.
     $proxy_suffix = "_ReadOnly";
 
-    if($objProperty->get_readable() ne 1)
+    if (!$objProperty->get_readable())
     {
       $self->output_wrap_failed($name, "attempt to wrap write-only and construct-only property.");
       return;
     }
   }
-  elsif($objProperty->get_readable() ne 1)
+  elsif (!$objProperty->get_readable())
   {
     $proxy_suffix = "_WriteOnly";
   }
-  elsif($objProperty->get_writable() ne 1)
+  elsif (!$objProperty->get_writable())
   {
     $proxy_suffix = "_ReadOnly";
   }
@@ -938,6 +912,26 @@ sub output_wrap_any_property($$$$$$$$$$)
     }
   }
 
+  # Default value, if available:
+  my $default_value = $objProperty->get_default_value();
+  if (defined($default_value))
+  {
+    DocsParser::convert_value_to_cpp(\$default_value);
+
+    # Add double quotes around a string value.
+    if ($objProperty->get_type() eq "GParamString")
+    {
+      $default_value = "\"" . $default_value . "\"";
+    }
+    $default_value = "Default value: $default_value";
+    add_m4_quotes(\$default_value);
+    if ($documentation ne "")
+    {
+      $documentation .= "\n   *\n   * ";
+    }
+    $documentation .= $default_value;
+  }
+
   #Declaration:
   if($deprecated ne "")
   {
